<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lg">
<context>
    <name>SelectWnd</name>
    <message>
        <location filename="../selectwnd.ui" line="14"/>
        <source>LXQt Mouse Theme Configuration</source>
        <translation>Enteekateeka y&apos;olulyo lw&apos;akasongesebwa olwa mu LXQt</translation>
    </message>
    <message>
        <location filename="../selectwnd.ui" line="20"/>
        <source>Select the cursor theme you want to use (hover preview to test cursor). &lt;b&gt;LXQt session needs restart after this change&lt;/b&gt;:</source>
        <translation>Londa olulyo lw&apos;akasonga lw&apos;oyagala okukozesa (Koona ku linya lya lwo akasonga kateeke awalabika obufaananyi olyoke osobole okulaba bwe kafuuka). &lt;br&gt;&lt;b&gt;Ddamu okutandika olutuula lwa LXQt by&apos;olonze bisobole okukwata&lt;/b&gt;:</translation>
    </message>
    <message>
        <location filename="../selectwnd.ui" line="104"/>
        <source>&amp;Install New Theme...</source>
        <translation>&amp;Nona olulyo olupya...</translation>
    </message>
    <message>
        <location filename="../selectwnd.ui" line="72"/>
        <source>LXQt session needs restart to view this change.</source>
        <translation>Ddamu okutandika olutuula lwa LXQt by&apos;okyusizza bisobole okukwata.</translation>
    </message>
    <message>
        <location filename="../selectwnd.ui" line="111"/>
        <source>&amp;Remove Theme</source>
        <translation>&amp;Olulyo lugyewo</translation>
    </message>
    <message>
        <location filename="../selectwnd.ui" line="65"/>
        <source>Size:</source>
        <translation>Bunene:</translation>
    </message>
    <message>
        <location filename="../selectwnd.cpp" line="231"/>
        <source>XCurTheme error</source>
        <translation>XCurTheme ezzeeko kiremya</translation>
    </message>
    <message>
        <location filename="../selectwnd.cpp" line="232"/>
        <source>You can&apos;t remove active theme!</source>
        <translation>Tosobola okugyawo olulyo nga lukozesebwa!</translation>
    </message>
</context>
<context>
    <name>WarningLabel</name>
    <message>
        <location filename="../warninglabel.ui" line="14"/>
        <source>Form</source>
        <translation>Awajjuzibwa</translation>
    </message>
    <message>
        <location filename="../warninglabel.ui" line="44"/>
        <source>LXQt could not find any cursor theme. The default X11 cursor theme will be used instead. LXQt looked in the following directories:</source>
        <translation>LXQt tezuddeyo ndyo za kasongesebwa. Ejjakukozesamu olulyo olujjira ku X11. LXQt enoonyezza mu materekero gano:</translation>
    </message>
    <message>
        <location filename="../warninglabel.ui" line="54"/>
        <source>Show...</source>
        <translation>Laga...</translation>
    </message>
</context>
<context>
    <name>XCursorThemeModel</name>
    <message>
        <location filename="../thememodel.cpp" line="62"/>
        <source>Name</source>
        <translation>Linnya</translation>
    </message>
    <message>
        <location filename="../thememodel.cpp" line="63"/>
        <source>Description</source>
        <translation>Okunnyonyola</translation>
    </message>
</context>
</TS>
